@@ -686,9 +686,8 @@ OC.L10N.register(
     "Blur" : "Emborrinar",
     "Upload" : "Xunir",
     "Files" : "Ficheros",
-    "Message sent" : "Unvióse'l mensaxe",
-    "Deleting message" : "Desaniciando'l mensaxe",
-    "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
+    "(edited)" : "(editóse)",
+    "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
     "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
     "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
     "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
@@ -713,6 +712,9 @@ OC.L10N.register(
     "Translate message" : "Traducir el mensaxe",
     "Translating" : "Traduciendo",
     "Copy translated text" : "Copiar el testu traducíu",
+    "Message sent" : "Unvióse'l mensaxe",
+    "Deleting message" : "Desaniciando'l mensaxe",
+    "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
     "Contact" : "Contautu",
     "Sending message" : "Unviando'l mensaxe",
     "Not enough free space to upload file" : "Nun hai abondu espaciu llibre pa xubir el ficheru",
@@ -726,9 +728,9 @@ OC.L10N.register(
     "Poll • Ended" : "Encuesta • Finó",
     "Poll" : "Encuesta",
     "See results" : "Ver los resultaos",
+    "Reactions" : "Reaiciones",
     "Show all reactions" : "Amosar toles reaiciones",
     "Add more reactions" : "Amestar más reaiciones",
-    "Reactions" : "Reaiciones",
     "No messages" : "Nun hai nengún mensaxe",
     "Add participants" : "Amestar participantes",
     "Conversation visibility" : "Visibilidá de la conversación",
@@ -769,7 +771,6 @@ OC.L10N.register(
     "Submit vote" : "Unviar el votu",
     "Change your vote" : "Cambiar el votu",
     "End poll" : "Finar la encuesta",
-    "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
     "Send a message to \"{roomName}\"" : "¿Quies unviar un mensaxe a «{roomName}»?",
     "Show list of participants" : "Amosar la llista de participantes",
     "The message was sent to \"{roomName}\"" : "El mensaxe unvióse a «{roomName}»",
@@ -909,7 +910,6 @@ OC.L10N.register(
     "Team" : "Equipu",
     "You and {user0} left the call" : "Tu y {user0} colestis de la canal",
     "You: {lastMessage}" : "Tu: {lastMessage}",
-    "(edited)" : "(editóse)",
     "Leave this page" : "Colar d'esta páxina",
     "In conversation" : "Na conversación",
     "Error while clearing conversation history" : "Hebo un error mentanto se borraba l'historial de la conversación",
@@ -952,17 +952,12 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Reports" : "Informes",
     "Call summary" : "Resume de llamaes",
-    "You tried to call {user}" : "Tentesti de llamar a {user}",
     "You were invited to a conversation." : "Convidáronte a una conversación.",
-    "{user} invited you to a private conversation" : "{user} convidóte a una conversación privada",
-    "Copy conversation link" : "Copiar l'enllaz de la conversación",
     "Media settings" : "Configuración multimedia",
     "Normal call" : "Llamada normal",
     "Today" : "Güei",
     "Yesterday" : "Ayeri",
     "A week ago" : "Hai una selmana",
-    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
-    "Close" : "Zarrar",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada."
+    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"]
 },
 "nplurals=2; plural=(n != 1);");
