@@ -481,6 +481,7 @@ OC.L10N.register(
     "Blocked" : "Stanket",
     "Active" : "O labourat",
     "Expired" : "Termenet",
+    "Never" : "James",
     "The trial could not be requested. Please try again later." : "An amprouadenn na c'hell ket bezhañ goulennet. Klaskit en dro goude.",
     "The account could not be deleted. Please try again later." : "Neo ket posupl lemel ar c'hont. Klaskit en dro goude",
     "URL of this Nextcloud instance" : "URL an azgoulenn Nextcloud",
@@ -493,6 +494,7 @@ OC.L10N.register(
     "Created at" : "Krouet da",
     "Expires at" : "Termen da",
     "Limits" : "Bevennoù",
+    "No" : "Nann",
     "Delete the signaling server account" : "Lemel ar c'hont arhent servijour",
     "_%n user_::_%n users_" : ["%n implijer","%n implijer","%n implijer","%n implijer","%n implijer"],
     "Status: Checking connection" : "Stad : Ho gwiriañ ar genstagadenn",
@@ -554,7 +556,6 @@ OC.L10N.register(
     "Personal" : "Personel",
     "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da zilemel  \"{displayName}\"?",
     "Leave conversation" : "Kuitaat an diviz",
-    "No" : "Nann",
     "Delete conversation" : "Dilemel an diviz",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
@@ -596,10 +597,6 @@ OC.L10N.register(
     "Translate" : "Treiñ",
     "Dismiss" : "Arrest",
     "Translate to" : "Treiñ e",
-    "Today" : "Hiziv",
-    "Yesterday" : "Dec'h",
-    "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
     "Add participants" : "Ouzhpennan tud",
     "Send message" : "Kas ur gemenadenn",
@@ -639,7 +636,6 @@ OC.L10N.register(
     "Search" : "Klask",
     "Start call" : "Kregiñ ar gemenadenn",
     "You will be able to join the call only after a moderator starts it." : "Posupl vo deoc'h mont er gemenadenn goude ma vo bet groget gant ar modertator.",
-    "Default" : "Dre ziouer",
     "Screensharing options" : "Dibaboù rannañ skramm",
     "Enable screensharing" : "Aotreañ ar rannan skramm",
     "Bad sent video and screen quality." : "Fall eo perzh ar skramm ha kasadenn ar video.",
@@ -658,15 +654,13 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
     "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
-    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
     "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
     "Show your screen" : "Diskouez ar skramm",
     "Stop screensharing" : "Echuañ ar rannadenn skramm",
     "Mute others" : "Lakaat ar re all mut",
     "Keep" : "Mirout",
     "Submit" : "Kinnig",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Kemenn hp meneg",
     "Mention myself" : "Meneg ac'hanon",
     "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
@@ -681,6 +675,7 @@ OC.L10N.register(
     "Media" : "Media",
     "Audio" : "Audio",
     "Other" : "All",
+    "Default" : "Dre ziouer",
     "Group" : "Stollad",
     "You: {lastMessage}" : "C'hwi : {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
@@ -717,14 +712,12 @@ OC.L10N.register(
     "You were invited to a conversation." : "Kouviet oc'h en un diviz",
     "Click the button below to join." : "Klikit war ar bouton evit mont",
     "Join »%s«" : "Mont da »%s«",
-    "{user} invited you to a private conversation" : "{user} en deus kouviet ac'hanoc'h en un diviz prevez",
-    "Copy conversation link" : "Eilañ al liamm diviz",
-    "Close" : "Serriñ",
+    "Today" : "Hiziv",
+    "Yesterday" : "Dec'h",
+    "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
     "Choose devices" : "Choazit un ardivink",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
-    "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
-    "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
-    "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
-    "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn."
+    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
+    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
