@@ -883,14 +883,9 @@ OC.L10N.register(
     "Blur" : "Sumennus",
     "Upload" : "Lähetä",
     "Files" : "Tiedostot",
-    "Message read by everyone who shares their reading status" : "Viesti luettu kaikkien niiden kanssa, jotka jakavat lukutilapäivityksensä",
-    "Message sent" : "Viesti lähetetty",
-    "Deleting message" : "Poistetaan viestiä",
-    "Message deleted successfully" : "Viesti poistettu onnistuneesti",
-    "Message could not be deleted because it is too old" : "Viestiä ei voitu poistaa, koska se on liian vanha",
-    "Only normal chat messages can be deleted" : "Vain normaaleja keskustelun viestejä on mahdollista poistaa",
-    "An error occurred while deleting the message" : "Virhe viestiä poistaessa",
-    "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
+    "(edited)" : "(muokattu)",
+    "The message has expired or has been deleted" : "Tämä viesti on vanhentunut tai se on poistettu",
+    "Cancel quote" : "Peruuta lainaus",
     "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
     "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
@@ -930,6 +925,14 @@ OC.L10N.register(
     "Translate to" : "Kohdekieli",
     "Translating" : "Käännetään",
     "Copy translated text" : "Kopioi käännetty teksti",
+    "Message read by everyone who shares their reading status" : "Viesti luettu kaikkien niiden kanssa, jotka jakavat lukutilapäivityksensä",
+    "Message sent" : "Viesti lähetetty",
+    "Deleting message" : "Poistetaan viestiä",
+    "Message deleted successfully" : "Viesti poistettu onnistuneesti",
+    "Message could not be deleted because it is too old" : "Viestiä ei voitu poistaa, koska se on liian vanha",
+    "Only normal chat messages can be deleted" : "Vain normaaleja keskustelun viestejä on mahdollista poistaa",
+    "An error occurred while deleting the message" : "Virhe viestiä poistaessa",
+    "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
     "Your browser does not support playing audio files" : "Selaimesi ei tue äänitiedostojen toistamista",
     "Contact" : "Yhteystieto",
     "Remove {fileName}" : "Poista {fileName}",
@@ -944,10 +947,10 @@ OC.L10N.register(
     "Copy code block" : "Kopioi koodilohko",
     "Poll" : "Kysely",
     "See results" : "Näytä tulokset",
+    "Reactions" : "Reaktiot",
     "No permission to post reactions in this conversation" : "Ei oikeutta lähettää reaktioita tähän keskusteluun",
     "Show all reactions" : "Näytä kaikki reaktiot",
     "Add more reactions" : "Lisää enemmän reaktioita",
-    "Reactions" : "Reaktiot",
     "No messages" : "Ei viestejä",
     "All messages have expired or have been deleted." : "Kaikki viestit ovat vanhentuneet tai ne on poistettu.",
     "Cancel search" : "Peruuta haku",
@@ -1014,8 +1017,6 @@ OC.L10N.register(
     "Submit vote" : "Lähetä ääni",
     "Change your vote" : "Muuta antamaasi ääntä",
     "End poll" : "Lopeta kysely",
-    "The message has expired or has been deleted" : "Tämä viesti on vanhentunut tai se on poistettu",
-    "Cancel quote" : "Peruuta lainaus",
     "Send a message to \"{roomName}\"" : "Lähetä viesti huoneeseen \"{roomName}\"",
     "Hide list of participants" : "Piilota osallistujaluettelo",
     "Show list of participants" : "Näytä osallistujaluettelo",
@@ -1232,7 +1233,6 @@ OC.L10N.register(
     "You added {user0} and {user1}" : "Lisäsit käyttäjät {user0} ja {user1}",
     "{user0} and {user1} joined the call" : "{user0} ja {user1} liittyivät puheluun",
     "You: {lastMessage}" : "Sinä: {lastMessage}",
-    "(edited)" : "(muokattu)",
     "(edited by you)" : "(muokattu toimestasi)",
     "(edited by a deleted user)" : "(muokattu poistetun käyttäjän toimesta)",
     "Leave this page" : "Poistu tältä sivulta",
@@ -1293,16 +1293,11 @@ OC.L10N.register(
     "Reports" : "Raportit",
     "Call summary" : "Puhelun yhteenveto",
     "Call summary - {title}" : "Puhelun yhteenveto - {title}",
-    "You tried to call {user}" : "Yritit soittaa käyttäjälle {user}",
     "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
     "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
     "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
     "Join »%s«" : "Liity »%s«",
-    "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
     "Always show the device preview screen before joining a call in this conversation." : "Näytä aina laitteen esikatselunäkymä ennen liittymistä puheluun tässä keskustelussa.",
-    "Copy conversation link" : "Kopioi keskustelulinkki",
-    "Filter unread mentions" : "Suodata lukemattomat maininnat",
-    "Filter unread messages" : "Suodata lukemattomat viestit",
     "Refresh devices list" : "Päivitä laitelista",
     "Media settings" : "Media-asetukset",
     "Always show preview for this conversation" : "Näytä aina esikatselu tälle keskustelulle",
@@ -1314,15 +1309,10 @@ OC.L10N.register(
     "Yesterday" : "Eilen",
     "A week ago" : "Viikko sitten",
     "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
-    "Close" : "Sulje",
     "Choose devices" : "Valitse laitteet",
     "Blur background" : "Sumenna tausta",
     "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
     "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
-    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk päivitettiin, lataa sivu uudelleen",
-    "An error happened when trying to share your file" : "Virhe yrittäessä jakaa tiedostoasi",
-    "Failed to join the conversation. Try to reload the page." : "Liittyminen keskusteluun epäonnistui. Päivitä sivu.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud on huoltotilassa, päivitä sivu"
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea."
 },
 "nplurals=2; plural=(n != 1);");
