@@ -779,13 +779,6 @@ OC.L10N.register(
     "Invalid path selected" : "Odabran nevažeći put",
     "Upload" : "Otpremi",
     "Files" : "Datoteke",
-    "Message read by everyone who shares their reading status" : "Poruku je pročitao svatko tko dijeli status čitanja",
-    "Message sent" : "Poruka poslana",
-    "Deleting message" : "Brisanje poruke",
-    "Message deleted successfully" : "Poruka je uspješno izbrisana",
-    "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
-    "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
-    "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
     "Reply" : "Odgovori",
     "Reply privately" : "Odgovori privatno",
     "Copy message link" : "Kopiraj poveznicu poruke",
@@ -797,6 +790,13 @@ OC.L10N.register(
     "The message has been forwarded to {selectedConversationName}" : "Poruka je proslijeđena u {selectedConversationName}",
     "Dismiss" : "Zanemari",
     "Go to conversation" : "Idi na razgovor",
+    "Message read by everyone who shares their reading status" : "Poruku je pročitao svatko tko dijeli status čitanja",
+    "Message sent" : "Poruka poslana",
+    "Deleting message" : "Brisanje poruke",
+    "Message deleted successfully" : "Poruka je uspješno izbrisana",
+    "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
+    "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
+    "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
     "Your browser does not support playing audio files" : "Vaš preglednik ne podržava reprodukciju zvučnih datoteka",
     "Contact" : "Kontakt",
     "{stack} in {board}" : "{stack} u {board}",
@@ -1061,28 +1061,18 @@ OC.L10N.register(
     "__language_name__" : "Hrvatski",
     "Tasks" : "Zadaci",
     "Notes" : "Bilješke",
-    "You tried to call {user}" : "Pokušali ste nazvati {user}",
     "%s invited you to a conversation." : "%s vas je pozvao u razgovor.",
     "You were invited to a conversation." : "Pozvani ste u razgovor.",
     "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
     "Join »%s«" : "Pridruži se »%s«",
-    "{user} invited you to a private conversation" : "{user} vas je pozvao u privatni razgovor",
     "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
-    "Copy conversation link" : "Kopiraj poveznicu za razgovor",
     "Today" : "Danas",
     "Yesterday" : "Jučer",
     "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
-    "Close" : "Zatvori",
     "Choose devices" : "Odaberi uređaje",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu prije upućivanja ili pridruživanja razgovoru.",
     "Blur background" : "Zamuti pozadinu",
     "Sharing your screen only works with Firefox version 52 or newer." : "Dijeljenje zaslona moguće je samo u pregledniku Firefox, inačice 52 ili novije.",
     "Screensharing extension is required to share your screen." : "Za dijeljenje zaslona potrebno je instalirati proširenje za dijeljenje zaslona.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Koristite se nekim drugim preglednikom za dijeljenje zaslona, primjerice preglednikom Firefox ili Chrome.",
-    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu",
-    "An error happened when trying to share your file" : "Došlo je do pogreške pri pokušaju dijeljenja datoteke",
-    "Failed to join the conversation. Try to reload the page." : "Pridruživanje razgovoru nije uspjelo. Pokušajte ponovno učitati stranicu.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud je u načinu održavanja, ponovno učitajte stranicu",
-    "Lost connection to signaling server. Try to reload the page manually." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušajte ponovno učitati stranicu."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Koristite se nekim drugim preglednikom za dijeljenje zaslona, primjerice preglednikom Firefox ili Chrome."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
