@@ -476,7 +476,6 @@ OC.L10N.register(
     "Blur" : "Móða",
     "Upload" : "Senda inn",
     "Files" : "Skrár",
-    "Message sent" : "Skilaboðin hafa verið send",
     "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
     "Set reminder for later today" : "Setja áminningu seinna í dag",
     "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
@@ -502,6 +501,7 @@ OC.L10N.register(
     "Translate to" : "Þýða yfir á",
     "Translating" : "Þýðing",
     "Copy translated text" : "Afrita þýddan texta",
+    "Message sent" : "Skilaboðin hafa verið send",
     "Contact" : "Tengiliður",
     "{stack} in {board}" : "{stack} á {board}",
     "Copy code block" : "Afrita kóðablokk",
@@ -601,11 +601,9 @@ OC.L10N.register(
     "You were invited to a conversation." : "Þér var boðið að taka þátt í samtali.",
     "Click the button below to join." : "Smelltu á hnappinn hér fyrir neðan til að taka þátt.",
     "Join »%s«" : "Taka þátt í »%s«",
-    "{user} invited you to a private conversation" : "{user} bauð þér að taka þátt í einkasímtali",
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
     "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
-    "Close" : "Loka",
     "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
     "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum."
