@@ -169,6 +169,7 @@ OC.L10N.register(
     "Decline" : "Одбиј",
     "New message" : "Нова порака",
     "Reminder" : "Потсетник",
+    "Notification" : "Известување",
     "Reminder: You in {call}" : "Потсетник: Вие во {call}",
     "Reminder: {user} in {call}" : "Потсетник: {user} во {call}",
     "Reminder: Deleted user in {call}" : "Потсетник: Избришан корисник во {call}",
@@ -571,6 +572,7 @@ OC.L10N.register(
     "Failed" : "Неуспешно",
     "OK" : "Добро",
     "Checking …" : "Проверка ...",
+    "Federated user" : "Федерален корисник",
     "Create rooms" : "Креирај соби",
     "Confirm" : "Потврди",
     "Reset" : "Ресетирање",
@@ -578,6 +580,7 @@ OC.L10N.register(
     "Back" : "Назад",
     "Cancel" : "Откажи",
     "Add participant \"{user}\"" : "Додади учесник \"{user}\"",
+    "Now" : "Сега",
     "Loading …" : "Се вчитува…",
     "From" : "Од",
     "To" : "До",
@@ -692,6 +695,7 @@ OC.L10N.register(
     "Talk settings" : "Параметри за Talk",
     "Users" : "Корисници",
     "Groups" : "Групи",
+    "Teams" : "Тимови",
     "No search results" : "Нема резултати од пребарувањето",
     "Users and groups" : "Корисници и групи",
     "Other sources" : "Други извори",
@@ -713,12 +717,13 @@ OC.L10N.register(
     "Blur" : "Замаглување",
     "Upload" : "Прикачи",
     "Files" : "Датотеки",
-    "Message sent" : "Пораката е испратена",
     "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
     "Set reminder for later today" : "Постави потсетник за денес покасно",
     "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
     "Set reminder for tomorrow" : "Постави потсетник за утре",
+    "This weekend – {timeLocale}" : "Овој викенд – {timeLocale}",
     "Set reminder for this weekend" : "Постави потсетник за овој викенд",
+    "Next week – {timeLocale}" : "Следна недела – {timeLocale}",
     "Set reminder for next week" : "Постави потсетник за наредната недела",
     "Clear reminder – {timeLocale}" : "Избришан потсетник – {timeLocale}",
     "Message text copied to clipboard" : "Пораката е копирана во клипборд",
@@ -737,6 +742,7 @@ OC.L10N.register(
     "Error while forwarding message" : "Грешка при препраќање на пораката",
     "The message has been forwarded to {selectedConversationName}" : "Пораката е препратена до {selectedConversationName}",
     "Dismiss" : "Отфрли",
+    "Message sent" : "Пораката е испратена",
     "Contact" : "Контакт",
     "{stack} in {board}" : "{stack} во {board}",
     "Open poll • You voted already" : "Отворена анкета •Имате гласано",
@@ -823,7 +829,7 @@ OC.L10N.register(
     "Resend invitation" : "Повторно испратете ги поканите",
     "Send call notification" : "Испрати известување за повик",
     "Grant all permissions" : "Додели ги сите дозволи",
-    "Remove all permissions" : "Острани ги сите дозволи",
+    "Remove all permissions" : "Отстрани ги сите дозволи",
     "Remove" : "Отстрани ",
     "Permissions modified for {displayName}" : "Дозволите на {displayName} се променети",
     "Add users or groups" : "Add users or groups",
@@ -871,6 +877,7 @@ OC.L10N.register(
     "Sounds" : "Звуци",
     "Play sounds when participants join or leave a call" : "Репродуцирајте звуци кога учесниците се придружуваат или оставаат повик",
     "Sounds for chat and call notifications can be adjusted in the personal settings." : "Звуците за чет и известувања за повици може да се прилагодат во личните поставки.",
+    "Performance" : "Перформанси",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Speed up your Talk experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
     "Focus the chat input" : "Фокусирајте го курсорот на разговорот",
@@ -1004,26 +1011,17 @@ OC.L10N.register(
     "iOS app" : "iOS апликација",
     "__language_name__" : "Македонски",
     "Tasks" : "Задачи",
-    "You tried to call {user}" : "Се обидовте да го повикате {user}",
     "%s invited you to a conversation." : "%s ве покани на разговор.",
     "You were invited to a conversation." : "Поканети сте на разговор.",
     "Click the button below to join." : "Кликнете на копчето подолу за да се приклучите.",
     "Join »%s«" : "Приклучете се »%s«",
-    "{user} invited you to a private conversation" : "{user} те покани на приватен разговор",
     "Always show the device preview screen before joining a call in this conversation." : "Секогаш прикажувај го екранот за преглед на уредот пред да се придружите на повик во овој разговор. ",
-    "Copy conversation link" : "копирај линк од разговорот",
     "Today" : "Денес",
     "Yesterday" : "Вчера",
     "_%n day ago_::_%n days ago_" : ["пред %n ден","пред %n дена"],
-    "Close" : "Затвори",
     "Choose devices" : "Избери уреди",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Разговорот беше ажуриран, треба повторно да ја вчитате страницата пред да започнете или да се придружите на повик.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
     "Screensharing extension is required to share your screen." : "Потребен е додаток за споделување на вашиот екран.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран.",
-    "Nextcloud Talk was updated, please reload the page" : "Разговорот е ажуриран, повторно вчитајте ја страната",
-    "An error happened when trying to share your file" : "Се случи грешка при обидот за споделување на датотека",
-    "Failed to join the conversation. Try to reload the page." : "Неуспешно приклучување кон разговорот, Пробајте да ја превчитате страницата.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Активиран е мод за одржавање, превчитајте ја страницата"
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
