@@ -767,13 +767,6 @@ OC.L10N.register(
     "Invalid path selected" : "Camin seleccionat invalid",
     "Upload" : "Cargament",
     "Files" : "Fichièrs",
-    "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
-    "Message sent" : "Messatge mandat",
-    "Deleting message" : "Supression del messatge",
-    "Message deleted successfully" : "Messatge corrèctament suprimit",
-    "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
-    "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
-    "An error occurred while deleting the message" : "Error pendent la supression del messatge",
     "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Add a reaction to this message" : "Apondre una reaccion a aqueste messatge",
     "Reply" : "Respondre",
@@ -792,6 +785,13 @@ OC.L10N.register(
     "Go to conversation" : "Anar a la conversacion",
     "Translate message" : "Traduire lo messatge",
     "Translating" : "Traduccion",
+    "Message read by everyone who shares their reading status" : "Messatge legit per tot lo monde que partejan lo estatut de lectura",
+    "Message sent" : "Messatge mandat",
+    "Deleting message" : "Supression del messatge",
+    "Message deleted successfully" : "Messatge corrèctament suprimit",
+    "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
+    "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
+    "An error occurred while deleting the message" : "Error pendent la supression del messatge",
     "Your browser does not support playing audio files" : "Vòstre navegador pren pas en carga la lectura dels fichièrs àudio",
     "Contact" : "Contacte",
     "{stack} in {board}" : "{stack} dins {board}",
@@ -1096,29 +1096,19 @@ OC.L10N.register(
     "iOS app" : "Aplicacion iOS",
     "__language_name__" : "Occitan",
     "Tasks" : "Prètzfaches",
-    "You tried to call {user}" : "Avètz ensajat de sonar {user}",
     "%s invited you to a conversation." : "%s vos a convidat a una conversacion.",
     "You were invited to a conversation." : "Òm vos a convidat a una conversacion.",
     "Click the button below to join." : "Clicatz sul boton per participar.",
     "Join »%s«" : "Rejónher « %s »",
-    "{user} invited you to a private conversation" : "{user} vos a convidat a una conversacion privada",
     "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
-    "Copy conversation link" : "Copiar lo ligam de conversacion",
     "Media settings" : "Paramètres dels mèdias",
     "Today" : "Uèi",
     "Yesterday" : "Ièr",
     "_%n day ago_::_%n days ago_" : ["fa %n jorn","fa %n jorns"],
-    "Close" : "Tampar",
     "Choose devices" : "Causir periferics",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
     "Blur background" : "Rèireplan trebol",
     "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
     "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
-    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
-    "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
-    "Failed to join the conversation. Try to reload the page." : "Impossible de rejónher la conversacion. Ensajatz de recargar la pagina.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
-    "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran."
 },
 "nplurals=2; plural=(n > 1);");
