@@ -649,7 +649,6 @@ OC.L10N.register(
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
     "Files" : "Fișiere",
-    "Message sent" : "Mesajul a fost transmis",
     "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
     "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
     "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
@@ -665,6 +664,7 @@ OC.L10N.register(
     "Translate" : "Tradu",
     "Set custom reminder" : "Setează memento particular",
     "Dismiss" : "Elimină",
+    "Message sent" : "Mesajul a fost transmis",
     "Contact" : "Contact",
     "{stack} in {board}" : "{stack} în {board}",
     "No messages" : "Niciun mesaj",
@@ -882,24 +882,16 @@ OC.L10N.register(
     "__language_name__" : "Română",
     "Tasks" : "Sarcini",
     "Notes" : "Notițe",
-    "You tried to call {user}" : "Ați încercat să apelați pe {user}",
     "%s invited you to a conversation." : "%s v-a invitat într-o conversație.",
     "You were invited to a conversation." : "Ați fost invitat într-o conversație.",
     "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
     "Join »%s«" : "Alăturați-vă »%s«",
-    "{user} invited you to a private conversation" : "{user} v-a invitat într-o conversație privată",
     "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
-    "Copy conversation link" : "Copiază linkul conversației",
-    "Filter unread mentions" : "Filtrează mențiunile necitite",
-    "Filter unread messages" : "Filtrează mesajele necitite",
     "Today" : "Azi",
     "Yesterday" : "Ieri",
     "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
-    "Close" : "Închide",
     "Choose devices" : "Selectați dispozitivele",
     "Blur background" : "Blurează fundalul",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului.",
-    "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
-    "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. "
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
