@@ -287,6 +287,7 @@ OC.L10N.register(
     "Blocked" : "Bị chặn",
     "Active" : "Hoạt động",
     "Expired" : "Đã hết hạn",
+    "Never" : "Không bao giờ",
     "The trial could not be requested. Please try again later." : "Không thể yêu cầu thử nghiệm. Vui lòng thử lại sau.",
     "The account could not be deleted. Please try again later." : "Không thể xóa tài khoản. Vui lòng thử lại sau.",
     "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Đối tác Struktur AG của chúng tôi cung cấp một dịch vụ mà một máy chủ báo hiệu được lưu trữ có thể được yêu cầu. Đối với điều này, bạn chỉ cần điền vào biểu mẫu bên dưới và vWorkspace của bạn sẽ yêu cầu nó. Sau khi máy chủ được thiết lập cho bạn, thông tin đăng nhập sẽ tự động được điền. Điều này sẽ ghi đè cài đặt máy chủ báo hiệu hiện có.",
@@ -300,6 +301,8 @@ OC.L10N.register(
     "Created at" : "Được tạo ra vào lúc",
     "Expires at" : "Hết hạn vào",
     "Limits" : "Giới hạn",
+    "Yes" : "Có",
+    "No" : "Không",
     "Delete the signaling server account" : "Xóa tài khoản máy chủ báo hiệu",
     "_%n user_::_%n users_" : ["%n người dùng"],
     "Installed version: {version}" : "Phiên bản đã cài đặt: {version}",
@@ -408,8 +411,6 @@ OC.L10N.register(
     "Error while deleting conversation" : "Lỗi khi xóa cuộc trò chuyện",
     "Be careful, these actions cannot be undone." : "Hãy cẩn thận, không thể hoàn tác những hành động này.",
     "Leave conversation" : "Rời khỏi cuộc đàm thoại",
-    "No" : "Không",
-    "Yes" : "Có",
     "Delete conversation" : "Xóa cuộc trò chuyện",
     "Password protection" : "Password protection",
     "Set a password" : "Đặt mật khẩu",
@@ -452,6 +453,7 @@ OC.L10N.register(
     "Add to favorites" : "Thêm vào ưa thích",
     "You need to promote a new moderator before you can leave the conversation." : "Bạn cần chọn người kiểm duyệt mới trước khi có thể rời khỏi cuộc trò chuyện.",
     "Conversation actions" : "Hoạt động cuộc trò chuyện",
+    "Home" : "Trang nhà",
     "No conversations found" : "Không tìm thấy cuộc trò chuyện nào",
     "An error occurred while performing the search" : "Đã xảy ra lỗi khi thực hiện tìm kiếm",
     "Conversation list" : "Danh sách cuộc trò chuyện",
@@ -479,13 +481,6 @@ OC.L10N.register(
     "Invalid path selected" : "Đường dẫn đã chọn không hợp lệ",
     "Upload" : "Tải lên",
     "Files" : "Tệp",
-    "Message read by everyone who shares their reading status" : "Tin nhắn được đọc bởi tất cả những người chia sẻ trạng thái đọc của họ",
-    "Message sent" : "Tin nhắn đã gửi",
-    "Deleting message" : "Đang xóa tin nhắn",
-    "Message deleted successfully" : "Đã xóa tin nhắn thành công",
-    "Message could not be deleted because it is too old" : "Không thể xóa tin nhắn vì nó quá cũ",
-    "Only normal chat messages can be deleted" : "Chỉ những tin nhắn trò chuyện bình thường mới có thể bị xóa",
-    "An error occurred while deleting the message" : "Đã xảy ra lỗi khi xóa tin nhắn",
     "Later today – {timeLocale}" : "Sau này - {timeLocale}",
     "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
     "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
@@ -497,15 +492,19 @@ OC.L10N.register(
     "Go to file" : "Tới tập tin",
     "Translate" : "Dịch",
     "Dismiss" : "Bỏ qua",
+    "Message read by everyone who shares their reading status" : "Tin nhắn được đọc bởi tất cả những người chia sẻ trạng thái đọc của họ",
+    "Message sent" : "Tin nhắn đã gửi",
+    "Deleting message" : "Đang xóa tin nhắn",
+    "Message deleted successfully" : "Đã xóa tin nhắn thành công",
+    "Message could not be deleted because it is too old" : "Không thể xóa tin nhắn vì nó quá cũ",
+    "Only normal chat messages can be deleted" : "Chỉ những tin nhắn trò chuyện bình thường mới có thể bị xóa",
+    "An error occurred while deleting the message" : "Đã xảy ra lỗi khi xóa tin nhắn",
     "Contact" : "Liên hệ",
     "{stack} in {board}" : "{stack} trong {board}",
     "Deck Card" : "Thẻ bài",
     "Sending message" : "Đang gửi tin nhắn",
     "Failed to send the message. Click to try again" : "Không gửi được tin nhắn. Bấm để thử lại",
     "Not enough free space to upload file" : "Không đủ dung lượng trống để tải tệp lên",
-    "Today" : "Hôm nay",
-    "Yesterday" : "Hôm qua",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Không có tin nhắn",
     "Create a new group conversation" : "Tạo một cuộc trò chuyện nhóm mới",
     "Add participants" : "Thêm người tham gia",
@@ -582,7 +581,6 @@ OC.L10N.register(
     "More actions" : "Nhiều hành động hơn",
     "Start call" : "Bắt đầu cuộc gọi",
     "You will be able to join the call only after a moderator starts it." : "Bạn sẽ chỉ có thể tham gia cuộc gọi sau khi người kiểm duyệt bắt đầu cuộc gọi.",
-    "Default" : "Mặc định",
     "Screensharing options" : "Tùy chọn chia sẻ màn hình",
     "Enable screensharing" : "Bật chia sẽ màn hình",
     "Bad sent video and screen quality." : "Chất lượng màn hình và video đã gửi kém.",
@@ -601,9 +599,6 @@ OC.L10N.register(
     "Screen sharing is not supported by your browser." : "Chia sẻ màn hình không được trình duyệt của bạn hỗ trợ.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang được tải qua HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
-    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
     "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
     "Show your screen" : "Hiện màn hình của bạn",
     "Stop screensharing" : "Ngừng chia sẽ màn hình",
@@ -611,6 +606,7 @@ OC.L10N.register(
     "Keep" : "Giữ",
     "Select a region" : "Chọn một khu vực",
     "Submit" : "Gửi đi",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Tin nhắn không đề cập",
     "Mention myself" : "Nhắc đến chính mình",
     "The conversation does not exist" : "Cuộc trò chuyện không tồn tại",
@@ -664,7 +660,9 @@ OC.L10N.register(
     "Audio" : "Âm thanh",
     "Other" : "Khác",
     "Show all files" : "Hiện tất cả tệp",
+    "Default" : "Mặc định",
     "Group" : "Nhóm",
+    "Team" : "Đội",
     "You: {lastMessage}" : "Bạn: {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
     "Leave this page" : "Rời khỏi trang này",
@@ -714,19 +712,15 @@ OC.L10N.register(
     "__language_name__" : "Tiếng Việt",
     "Tasks" : "Nhiệm vụ",
     "Notes" : "Ghi chú",
-    "You tried to call {user}" : "Bạn đã cố gắng gọi {user}",
     "%s invited you to a conversation." : "%s đã được mời vào cuộc trò chuyện",
     "You were invited to a conversation." : "Bạn đã được mời vào cuộc trò chuyện",
     "Click the button below to join." : "Click vào nút bên dưới để tham gia",
     "Join »%s«" : "Tham gia »%s«",
-    "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
-    "Copy conversation link" : "Sao chép liên kết cuộc trò chuyện",
-    "Close" : "Đóng",
+    "Today" : "Hôm nay",
+    "Yesterday" : "Hôm qua",
     "Choose devices" : "Chọn thiết bị",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "vWorkspace Talk đã được cập nhật, bạn cần tải lại trang trước khi có thể bắt đầu hoặc tham gia cuộc gọi.",
-    "Nextcloud Talk was updated, please reload the page" : "vWorkspace Talk đã được cập nhật, vui lòng tải lại trang",
-    "Failed to join the conversation. Try to reload the page." : "Không tham gia được cuộc trò chuyện. Hãy thử tải lại trang.",
-    "Nextcloud is in maintenance mode, please reload the page" : "vWorkspace đang ở chế độ bảo trì, vui lòng tải lại trang",
-    "Lost connection to signaling server. Try to reload the page manually." : "Mất kết nối với máy chủ báo hiệu. Cố gắng tải lại trang theo cách thủ công."
+    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
+    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn."
 },
 "nplurals=1; plural=0;");
