@@ -65,6 +65,7 @@ use OCA\Talk\Events\ReactionAddedEvent;
 use OCA\Talk\Events\ReactionRemovedEvent;
 use OCA\Talk\Events\RoomCreatedEvent;
 use OCA\Talk\Events\RoomDeletedEvent;
+use OCA\Talk\Events\RoomExtendedEvent;
 use OCA\Talk\Events\RoomModifiedEvent;
 use OCA\Talk\Events\RoomSyncedEvent;
 use OCA\Talk\Events\SessionLeftRoomEvent;
@@ -81,8 +82,10 @@ use OCA\Talk\Federation\Proxy\TalkV1\Notifier\RoomModifiedListener as TalkV1Room
 use OCA\Talk\Files\Listener as FilesListener;
 use OCA\Talk\Files\TemplateLoader as FilesTemplateLoader;
 use OCA\Talk\Flow\RegisterOperationsListener;
+use OCA\Talk\Listener\AddMissingIndicesListener;
 use OCA\Talk\Listener\BeforeUserLoggedOutListener;
 use OCA\Talk\Listener\BotListener;
+use OCA\Talk\Listener\CalDavEventListener;
 use OCA\Talk\Listener\CircleDeletedListener;
 use OCA\Talk\Listener\CircleEditedListener;
 use OCA\Talk\Listener\CircleMembershipListener;
@@ -94,6 +97,7 @@ use OCA\Talk\Listener\GroupMembershipListener;
 use OCA\Talk\Listener\NoteToSelfListener;
 use OCA\Talk\Listener\RestrictStartingCalls as RestrictStartingCallsListener;
 use OCA\Talk\Listener\SampleConversationsListener;
+use OCA\Talk\Listener\ThreadListener;
 use OCA\Talk\Listener\UserDeletedListener;
 use OCA\Talk\Maps\MapsPluginLoader;
 use OCA\Talk\Middleware\CanUseTalkMiddleware;
@@ -118,6 +122,7 @@ use OCA\Talk\SetupCheck\BackgroundBlurLoading;
 use OCA\Talk\SetupCheck\Configuration;
 use OCA\Talk\SetupCheck\FederationLockCache;
 use OCA\Talk\SetupCheck\HighPerformanceBackend;
+use OCA\Talk\SetupCheck\NotifyPush;
 use OCA\Talk\SetupCheck\RecordingBackend;
 use OCA\Talk\SetupCheck\SIPConfiguration;
 use OCA\Talk\Share\Listener as ShareListener;
@@ -129,10 +134,13 @@ use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
 use OCP\AppFramework\Bootstrap\IRegistrationContext;
+use OCP\Calendar\Events\CalendarObjectCreatedEvent;
+use OCP\Calendar\Events\CalendarObjectUpdatedEvent;
 use OCP\Collaboration\AutoComplete\AutoCompleteFilterEvent;
 use OCP\Collaboration\Resources\IProviderManager;
 use OCP\Collaboration\Resources\LoadAdditionalScriptsEvent;
 use OCP\Config\BeforePreferenceSetEvent;
+use OCP\DB\Events\AddMissingIndicesEvent;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Federation\ICloudFederationProvider;
 use OCP\Federation\ICloudFederationProviderManager;
@@ -169,6 +177,7 @@ class Application extends App implements IBootstrap {
 		parent::__construct(self::APP_ID, $urlParams);
 	}
 
+	#[\Override]
 	public function register(IRegistrationContext $context): void {
 		$context->registerMiddleWare(CanUseTalkMiddleware::class);
 		$context->registerMiddleWare(InjectionMiddleware::class);
@@ -227,6 +236,10 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(MessageParseEvent::class, SystemMessage::class, 9999);
 		$context->registerEventListener(MessageParseEvent::class, UserMention::class, -100);
 
+		// Calendar listeners
+		$context->registerEventListener(CalendarObjectCreatedEvent::class, CalDavEventListener::class);
+		$context->registerEventListener(CalendarObjectUpdatedEvent::class, CalDavEventListener::class);
+
 		// Files integration listeners
 		$context->registerEventListener(BeforeGuestJoinedRoomEvent::class, FilesListener::class);
 		$context->registerEventListener(BeforeUserJoinedRoomEvent::class, FilesListener::class);
@@ -312,6 +325,7 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(LobbyModifiedEvent::class, SignalingListener::class);
 		$context->registerEventListener(BeforeRoomSyncedEvent::class, SignalingListener::class);
 		$context->registerEventListener(RoomSyncedEvent::class, SignalingListener::class);
+		$context->registerEventListener(RoomExtendedEvent::class, SignalingListener::class);
 
 		$context->registerEventListener(ChatMessageSentEvent::class, SignalingListener::class);
 		$context->registerEventListener(SystemMessageSentEvent::class, SignalingListener::class);
@@ -328,6 +342,9 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(GuestJoinedRoomEvent::class, SignalingListener::class);
 		$context->registerEventListener(UserJoinedRoomEvent::class, SignalingListener::class);
 
+		// Threads listeners
+		$context->registerEventListener(AttendeesRemovedEvent::class, ThreadListener::class);
+
 		// Video verification
 		$context->registerEventListener(BeforeUserJoinedRoomEvent::class, PublicShareAuthListener::class);
 		$context->registerEventListener(BeforeGuestJoinedRoomEvent::class, PublicShareAuthListener::class);
@@ -341,6 +358,9 @@ class Application extends App implements IBootstrap {
 		$context->registerSearchProvider(CurrentMessageSearch::class);
 		$context->registerSearchProvider(MessageSearch::class);
 
+		// Fix database issues
+		$context->registerEventListener(AddMissingIndicesEvent::class, AddMissingIndicesListener::class);
+
 		$context->registerDashboardWidget(TalkWidget::class);
 
 		$context->registerNotifierService(Notifier::class);
@@ -356,11 +376,13 @@ class Application extends App implements IBootstrap {
 		$context->registerSetupCheck(Configuration::class);
 		$context->registerSetupCheck(HighPerformanceBackend::class);
 		$context->registerSetupCheck(FederationLockCache::class);
+		$context->registerSetupCheck(NotifyPush::class);
 		$context->registerSetupCheck(RecordingBackend::class);
 		$context->registerSetupCheck(SIPConfiguration::class);
 		$context->registerSetupCheck(BackgroundBlurLoading::class);
 	}
 
+	#[\Override]
 	public function boot(IBootContext $context): void {
 		$context->injectFn([$this, 'registerCollaborationResourceProvider']);
 		$context->injectFn([$this, 'registerClientLinks']);
