@@ -30,6 +30,7 @@ use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\Attribute\PublicPage;
+use OCP\AppFramework\Http\Attribute\RequestHeader;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\OCSController;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -88,12 +89,12 @@ class SignalingController extends OCSController {
 	 * @return bool
 	 */
 	private function validateRecordingBackendRequest(string $data): bool {
-		$random = $this->request->getHeader('Talk-Recording-Random');
+		$random = $this->request->getHeader('talk-recording-random');
 		if (empty($random) || strlen($random) < 32) {
 			$this->logger->debug('Missing random');
 			return false;
 		}
-		$checksum = $this->request->getHeader('Talk-Recording-Checksum');
+		$checksum = $this->request->getHeader('talk-recording-checksum');
 		if (empty($checksum)) {
 			$this->logger->debug('Missing checksum');
 			return false;
@@ -117,10 +118,12 @@ class SignalingController extends OCSController {
 	#[BruteForceProtection(action: 'talkRecordingSecret')]
 	#[BruteForceProtection(action: 'talkFederationAccess')]
 	#[OpenAPI(tags: ['internal_signaling', 'external_signaling'])]
+	#[RequestHeader(name: 'talk-recording-random', description: 'Random seed used to generate the request checksum', indirect: true)]
+	#[RequestHeader(name: 'talk-recording-checksum', description: 'Checksum over the request body to verify authenticity from the recording backend', indirect: true)]
 	public function getSettings(string $token = ''): DataResponse {
 		$isRecordingRequest = false;
 
-		if (!empty($this->request->getHeader('Talk-Recording-Random')) || !empty($this->request->getHeader('Talk-Recording-Checksum'))) {
+		if (!empty($this->request->getHeader('talk-recording-random')) || !empty($this->request->getHeader('talk-recording-checksum'))) {
 			if (!$this->validateRecordingBackendRequest('')) {
 				$response = new DataResponse(null, Http::STATUS_UNAUTHORIZED);
 				$response->throttle(['action' => 'talkRecordingSecret']);
@@ -634,7 +637,7 @@ class SignalingController extends OCSController {
 	 * @return string
 	 */
 	protected function getInputStream(): string {
-		return file_get_contents('php://input');
+		return (string)file_get_contents('php://input');
 	}
 
 	/**
@@ -651,6 +654,8 @@ class SignalingController extends OCSController {
 	#[OpenAPI(scope: 'backend-signaling')]
 	#[PublicPage]
 	#[BruteForceProtection(action: 'talkSignalingSecret')]
+	#[RequestHeader(name: 'spreed-signaling-random', description: 'Random seed used to generate the request checksum', indirect: true)]
+	#[RequestHeader(name: 'spreed-signaling-checksum', description: 'Checksum over the request body to verify authenticity from the signaling backend', indirect: true)]
 	public function backend(): DataResponse {
 		$json = $this->getInputStream();
 		if (!$this->validateBackendRequest($json)) {
